"""
.. include:: ../README.md

"""

from .colors import *
from .plot import *
from .style import *
from .text import *

__version__ = '0.4.2'
